Index: trunk/ppSim/src/ppSimPhotomReadoutForce.c
===================================================================
--- trunk/ppSim/src/ppSimPhotomReadoutForce.c	(revision 21183)
+++ trunk/ppSim/src/ppSimPhotomReadoutForce.c	(revision 21365)
@@ -12,5 +12,5 @@
     }
 
-# if 0    
+# if 0
     // set the photcode for this image
     if (!psphotAddPhotcode (recipe, config, view, "PPSIM.FAKE.CHIP")) {
@@ -22,5 +22,5 @@
     // *** in this section, perform the photometry for real + force sources on PPSIM.FORCE.CHIP ***
 
-    // find the currently selected readout. 
+    // find the currently selected readout.
     // we always perform photometry on the mosaiced chip
     pmReadout  *readout = pmFPAfileThisReadout (config->files, view, "PPSIM.FORCE.CHIP");
@@ -35,6 +35,6 @@
     psAssert (forceSources, "failed to load force photometry sources");
 
-    // Generate the mask and weight images, including the user-defined analysis region of interest
-    psphotSetMaskAndWeight (config, readout, recipe);
+    // Generate the mask and variance images, including the user-defined analysis region of interest
+    psphotSetMaskAndVariance (config, readout, recipe);
 
     // XXX need to define the source pixels
@@ -46,13 +46,13 @@
     psArray *realSources = psArrayAlloc (realMeasuredSources->n);
     for (int i = 0; i < realMeasuredSources->n; i++) {
-	realSources->data[i] = pmSourceCopy (realMeasuredSources->data[i]);
+        realSources->data[i] = pmSourceCopy (realMeasuredSources->data[i]);
     }
 
     // load the psf model, if suppled.  FWHM_X,FWHM_Y,etc are saved in the recipe
-    // this function uses PSPHOT.PSF.LOAD as the pmFPAfile 
+    // this function uses PSPHOT.PSF.LOAD as the pmFPAfile
     pmPSF *psf = psphotLoadPSF (config, view, recipe);
     assert (psf);
 
-    // remove all sources 
+    // remove all sources
     psphotRemoveAllSources (realSources, recipe);
 
@@ -69,5 +69,5 @@
 
     // XXX fake sources should measure peak->x,y, force sources should not
-    psImageMaskType maskVal = 0xff; 
+    psImageMaskType maskVal = 0xff;
     psImage *significance = psphotSignificanceImage (readout, recipe, 1, maskVal);
     ppSimDetections (significance, recipe, forceSources);
@@ -83,5 +83,5 @@
     psphotGuessModels (config, readout, realSources, psf);
     psphotGuessModels (config, readout, forceSources, psf);
-    
+
     // linear fit to real + force sources
     psArray *sources = ppSimMergeSources (realSources, forceSources);
@@ -106,6 +106,6 @@
     pmReadout *forceReadout = pmFPAfileThisReadout (config->files, view, "PPSIM.FORCE.SOURCES");
     if (!forceReadout) {
-	forceReadout = pmReadoutAlloc (forceCell);
-	psFree (forceReadout); // there is a copy on 'cell' as well
+        forceReadout = pmReadoutAlloc (forceCell);
+        psFree (forceReadout); // there is a copy on 'cell' as well
     }
     psAssert (forceReadout, "no forceReadout?");
